aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/Class/Device/RNDIS.h
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2009-08-05 06:36:31 +0000
committerDean Camera <dean@fourwalledcubicle.com>2009-08-05 06:36:31 +0000
commitc5038f1bf44aea75f1ae1ed035cb7d523ccfdacb (patch)
tree5cf62e8642cc53c49eb28f973db843df5f047ba3 /LUFA/Drivers/USB/Class/Device/RNDIS.h
parent357ccc577bc6f8710ff942019e16cfa6a08466b7 (diff)
downloadlufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.tar.gz
lufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.tar.bz2
lufa-c5038f1bf44aea75f1ae1ed035cb7d523ccfdacb.zip
Renamed all library events to properly seperate out Device and Host mode events. Changed the firing conditions for some events to ensure that events are fired by their own USB mode only.
Remove VBUS events - not needed as the library takes care of VBUS detection and feedback on supported AVRs via the USB_Device_Connected and USB_Device_Disconnected events. Fixed incorrect Host state assignment in the incomplete BluetoothHost demo.
Diffstat (limited to 'LUFA/Drivers/USB/Class/Device/RNDIS.h')
-rw-r--r--LUFA/Drivers/USB/Class/Device/RNDIS.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/LUFA/Drivers/USB/Class/Device/RNDIS.h b/LUFA/Drivers/USB/Class/Device/RNDIS.h
index 8855aac17..d9a5d7f0b 100644
--- a/LUFA/Drivers/USB/Class/Device/RNDIS.h
+++ b/LUFA/Drivers/USB/Class/Device/RNDIS.h
@@ -103,7 +103,7 @@
/* Function Prototypes: */
/** Configures the endpoints of a given RNDIS interface, ready for use. This should be linked to the library
- * \ref EVENT_USB_ConfigurationChanged() event so that the endpoints are configured when the configuration
+ * \ref EVENT_USB_Device_ConfigurationChanged() event so that the endpoints are configured when the configuration
* containing the given HID interface is selected.
*
* \param[in,out] RNDISInterfaceInfo Pointer to a structure containing a RNDIS Class configuration and state.
@@ -113,11 +113,11 @@
bool RNDIS_Device_ConfigureEndpoints(USB_ClassInfo_RNDIS_Device_t* const RNDISInterfaceInfo);
/** Processes incomming control requests from the host, that are directed to the given RNDIS class interface. This should be
* linked to the library \ref EVENT_USB_UnhandledControlPacket() event.
*
* \param[in,out] RNDISInterfaceInfo Pointer to a structure containing a RNDIS Class configuration and state.
*/
- void RNDIS_Device_ProcessControlPacket(USB_ClassInfo_RNDIS_Device_t* const RNDISInterfaceInfo);
+ void RNDIS_Device_ProcessControlRequest(USB_ClassInfo_RNDIS_Device_t* const RNDISInterfaceInfo);
/** General management task for a given HID class interface, required for the correct operation of the interface. This should
* be called frequently in the main program loop, before the master USB management task \ref USB_USBTask().
@@ -113,11 +113,11 @@
bool RNDIS_Device_ConfigureEndpoints(USB_ClassInfo_RNDIS_Device_t* const RNDISInterfaceInfo);
/** Processes incomming control requests from the host, that are directed to the given RNDIS class interface. This should be
- * linked to the library \ref EVENT_USB_UnhandledControlPacket() event.
+ * linked to the library \ref EVENT_USB_Device_UnhandledControlRequest() event.
*
* \param[in,out] RNDISInterfaceInfo Pointer to a structure containing a RNDIS Class configuration and state.